from setuptools import setup, find_packages
setup(
    name = "trileans",
    version = "1.5.2",
    packages = ['trileans'],
    author = "rittbys",
    description = "Trileans are three-valued objects.",
    license = "MIT",
    keywords = "Trileans objects",
    url = "https://github.com/rittbys/Trileans",
    classifiers=[
	'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4'
    ]
)
